==> abe-cli-0.0.4.tgz: package/src/server/public/scripts/modules/EditorUtils.js <==
import {IframeNode} from '../utils/iframe'
import Handlebars from 'handlebars'

export default class EditorUtils {

  static checkAttribute() {
  	let formAbes = document.querySelectorAll('.form-abe')

    Array.prototype.forEach.call(formAbes, (formAbe) => {
      var hide = IframeNode('#page-template', '[data-if-empty-clear="' + formAbe.getAttribute('data-id') + '"]')[0]
      if(typeof hide !== 'undefined' && hide !== null) {
        if (formAbe.value === '') {
          hide.style.display = 'none'
        }else {
          hide.style.display = ''
        }
      }
    })
  }

  static scrollToInputElement(target) {
    var dataLink = target.getAttribute('data-id-link')
    var attrAbe = (typeof dataLink !== 'undefined' && dataLink !== null) ? 'data-abe-text' : 'data-abe'
    var id = target.getAttribute('data-id')
    var nodes = IframeNode('#page-template', '[' + attrAbe + '="' + id + '"]')

    if(typeof nodes === 'undefined' || nodes === null || nodes.length === 0) {
      var blockContent = IframeNode('#page-template', '.insert-' + id.split('[')[0])[0]
      var blockHtml = unescape(blockContent.innerHTML).replace(/\[0\]\./g, id.split('[')[0] + '[0]-')
      blockContent.outerHTML = blockHtml + blockContent.outerHTML;
      nodes = IframeNode('#page-template', '[' + attrAbe + '="' + id + '"]')
    }

    Array.prototype.forEach.call(nodes, (node) => {
      node.classList.add('select-border')
    })
    
    // scroll to DOM node
    if(typeof nodes[0] !== 'undefined' && nodes[0] !== null) {
      var bounds = nodes[0].getBoundingClientRect()
      var w = document.getElementById('page-template').contentWindow
      w.scroll(0, w.scrollY + bounds.top + (bounds.height * 0.5) - (window.innerHeight * 0.5))
    }
  }

  static getAttr(target) {
    var dataLink = target.getAttribute('data-id-link')
    var attrAbe = (typeof dataLink !== 'undefined' && dataLink !== null) ? 'data-abe-text' : 'data-abe'
    var id = target.getAttribute('data-id')

    return {
      abe: attrAbe,
      id: id
    }
  }

  static getNode(attr) {
    var nodes = IframeNode('#page-template', '[' + attr.abe + '="' + attr.id + '"]')

    if(typeof nodes === 'undefined' || nodes === null) {
      var blockContent = IframeNode('#page-template', '.insert-' + attr.id.split('[')[0])[0]
      var blockHtml = unescape(blockContent.innerHTML).replace(/\[0\]\./g, attr.id.split('[')[0] + '[0]-')
      blockContent.insertBefore(blockHtml, blockContent)
      nodes = IframeNode('#page-template', '[' + attr.abe + '="' + attr.id + '"]')
    }

    Array.prototype.forEach.call(nodes, (node) => {
      node.classList.add('select-border')
    })

    return nodes
  }

  /**
   * get input value and set to iframe html
   * @param  {Object} node  html node
   * @param  {Object} input input elem
   * @return {null}
   */
  static formToHtml(node, input) {
    var val = input.value
    var placeholder = input.getAttribute('placeholder')
    if(typeof placeholder === 'undefined' || placeholder === 'undefined' || placeholder === null) {
      placeholder = ""
    }
    if(val.replace(/^\s+|\s+$/g, '').length < 1) {
      val = placeholder
    }

    switch(input.nodeName.toLowerCase()){
      case 'input':
        var dataAbeAttr = node.getAttribute('data-abe-attr')
        if(typeof dataAbeAttr !== 'undefined' && dataAbeAttr !== null) {
           node.setAttribute(dataAbeAttr, val)
        }else {
          node.innerHTML = val
        }
      break
      case 'textarea':
        node.innerHTML = (input.classList.contains('form-rich')) ? input.parentNode.querySelector('[contenteditable]').innerHTML : val
        break;
      case 'select':
        var key = node.getAttribute('data-abe')
        var dataAbeAttr = node.getAttribute('data-abe-attr')
        var dataAbeAttrEscaped = unescape(node.getAttribute('data-abe-attr-escaped'))
        var option = input.querySelector('option:checked')
        if(typeof option !== 'undefined' && option !== null) {
          val = option.value
          if(typeof dataAbeAttr !== 'undefined' && dataAbeAttr !== null) {
            var template = Handlebars.compile(dataAbeAttrEscaped, {noEscape: true})
            var json = {}
            json[key] = val
            var compiled = template(json)
            node.setAttribute(dataAbeAttr, compiled)
          }else {
            node.innerHTML = val
          }
        }
      break
    }
  }
}

==> abe-cli-0.2.3.tgz: package/src/server/public/scripts/modules/EditorUtils.js <==
import {IframeNode} from '../utils/iframe'
import Handlebars from 'handlebars'

export default class EditorUtils {

  static checkAttribute() {
  	let formAbes = document.querySelectorAll('.form-abe')

    Array.prototype.forEach.call(formAbes, (formAbe) => {
      var hide = IframeNode('#page-template', '[data-if-empty-clear="' + formAbe.getAttribute('data-id') + '"]')[0]
      if(typeof hide !== 'undefined' && hide !== null) {
        if (formAbe.value === '') {
          hide.style.display = 'none'
        }else {
          hide.style.display = ''
        }
      }
    })
  }

  static scrollToInputElement(target) {
    var dataLink = target.getAttribute('data-id-link')
    var id = target.getAttribute('data-id')
    var nodes = IframeNode('#page-template', '[data-abe="' + id + '"]')

    if(typeof nodes === 'undefined' || nodes === null || nodes.length === 0) {
      var blockContent = IframeNode('#page-template', '.insert-' + id.split('[')[0])[0]
      var blockHtml = unescape(blockContent.innerHTML).replace(/\[0\]\./g, id.split('[')[0] + '[0]-')
      blockContent.outerHTML = blockHtml + blockContent.outerHTML
      nodes = IframeNode('#page-template', '[data-abe="' + id + '"]')
    }

    Array.prototype.forEach.call(nodes, (node) => {
      node.classList.add('select-border')
    })
    
    // scroll to DOM node
    if(typeof nodes[0] !== 'undefined' && nodes[0] !== null) {
      var bounds = nodes[0].getBoundingClientRect()
      var w = document.getElementById('page-template').contentWindow
      w.scroll(0, w.scrollY + bounds.top + (bounds.height * 0.5) - (window.innerHeight * 0.5))
    }
  }

  static getAttr(target) {
    var dataLink = target.getAttribute('data-id-link')
    var id = target.getAttribute('data-id')

    return {
      abe: 'data-abe',
      id: id
    }
  }

  static getNode(attr) {
    var nodes = IframeNode('#page-template', '[' + attr.abe + '="' + attr.id + '"]')

    if(typeof nodes === 'undefined' || nodes === null) {
      var blockContent = IframeNode('#page-template', '.insert-' + attr.id.split('[')[0])[0]
      var blockHtml = unescape(blockContent.innerHTML).replace(/\[0\]\./g, attr.id.split('[')[0] + '[0]-')
      blockContent.insertBefore(blockHtml, blockContent)
      nodes = IframeNode('#page-template', '[' + attr.abe + '="' + attr.id + '"]')
    }

    Array.prototype.forEach.call(nodes, (node) => {
      node.classList.add('select-border')
    })

    return nodes
  }

  /**
   * get input value and set to iframe html
   * @param  {Object} node  html node
   * @param  {Object} input input elem
   * @return {null}
   */
  static formToHtml(node, input) {
    var val = input.value
    var placeholder = input.getAttribute('placeholder')
    if(typeof placeholder === 'undefined' || placeholder === 'undefined' || placeholder === null) {
      placeholder = ""
    }
    if(val.replace(/^\s+|\s+$/g, '').length < 1) {
      val = placeholder
    }

    switch(input.nodeName.toLowerCase()){
      case 'input':
        var dataAbeAttr = node.getAttribute('data-abe-attr')
        if(typeof dataAbeAttr !== 'undefined' && dataAbeAttr !== null) {
           node.setAttribute(dataAbeAttr, val)
        }else {
          node.innerHTML = val
        }
      break
      case 'textarea':
        node.innerHTML = (input.classList.contains('form-rich')) ? input.parentNode.querySelector('[contenteditable]').innerHTML : val
        break;
      case 'select':
        var key = node.getAttribute('data-abe')
        var dataAbeAttr = node.getAttribute('data-abe-attr')
        var dataAbeAttrEscaped = unescape(node.getAttribute('data-abe-attr-escaped'))
        var option = input.querySelector('option:checked')
        if(typeof option !== 'undefined' && option !== null) {
          val = option.value
          if(typeof dataAbeAttr !== 'undefined' && dataAbeAttr !== null) {
            var template = Handlebars.compile(dataAbeAttrEscaped, {noEscape: true})
            var json = {}
            json[key] = val
            var compiled = template(json)
            node.setAttribute(dataAbeAttr, compiled)
          }else {
            node.innerHTML = val
          }
        }
      break
    }
  }
}
